@@ -61,40 +61,22 @@
 #include <locale.h>
 #include <search.h>
 
-#include "config.h"
-
-#ifdef HAVE_GETOPT_LONG
 #include <getopt.h>
-#endif
 
-#ifdef MCHECK
-#include <mcheck.h>
-#endif
-#ifdef HAVE_READLINE
 #include <readline/readline.h>
 #include <readline/history.h>
-#endif
 
 #include "cmds.h"
 #include "stack.h"
 #include "utils.h"
 
-#ifdef HAVE_READLINE
 void initialize_readline(int interactive);
 
 extern char *command_generator (const char *text, int state);
-#endif
 
-#ifdef HAVE_GETTEXT
 #include <libintl.h>
 
 #define  _(String) gettext(String)
-#else
-#define  _(String) (String)
-
-#define textdomain(Domain)
-#define bindtextdomain(Package, Directory)
-#endif
 
 extern int  yyparse(void);
 extern void yy_scan_string(char *s);
@@ -105,14 +87,6 @@ extern struct var vartab[];
 const char *progname, *filename;
 int done;
 
-#ifndef HAVE_POW10
-extern double pow10(double y);
-#endif
-#ifndef HAVE_POW2
-extern double pow2(double y);
-#endif
-
-#ifdef HAVE_GETOPT_LONG
 struct option const long_options[] =
 {
   {"help",     no_argument, 0, 'h'},
@@ -121,7 +95,6 @@ struct option const long_options[] =
   {"license",  no_argument, 0, 'L'},
   {(char *)0, 0,           0, (char)0}
 };
-#endif
 
 /* print a short usage statement. Indicate that the argument must be quoted. */
 static void usage(int showhelp)
@@ -136,7 +109,6 @@ static void usage(int showhelp)
   }
 }
 
-#ifdef HAVE_READLINE
 /* Tell the GNU Readline library how to complete.  We want to try to complete
    on command names if this is the first word in the line. */
 void initialize_readline(int interactive)
@@ -168,7 +140,6 @@ char **rpncalc_completion(const char *text, int start, int end)
 {
   return rl_completion_matches (text, &command_generator);
 }
-#endif
 
 int main(int argc, char *argv[])
 {
@@ -183,12 +154,8 @@ int main(int argc, char *argv[])
   bindtextdomain(PACKAGE,LOCALEDIR);
   textdomain(PACKAGE);
 
-#ifdef HAVE_GETOPT_LONG
   while ((c = getopt_long(argc, argv, "hVWL",
                           long_options, (int *) 0)) != EOF) {
-#else
-  while ((c = getopt(argc, argv, "hVWL")) != EOF) {
-#endif
 
     switch (c) {
       case 0  : break;
@@ -228,9 +195,8 @@ int main(int argc, char *argv[])
     int interactive=isatty(0);
     char *line;
 
-#ifdef HAVE_READLINE
     initialize_readline(interactive);
-#endif
+
     if (interactive) {
       fprintf(stderr,"%s version %s. Copyright (c) 1993-2004 David Frey et. al.\n",
               progname, VERSION);
@@ -239,30 +205,23 @@ int main(int argc, char *argv[])
       fprintf(stderr, _("For details, type `warranty'.\n"));
       fprintf(stderr, _("Type `quit' to quit and `?' to get a summary.\n"));
 
-#ifdef HAVE_READLINE
       using_history();
-#endif
     }
 
     filename="stdin"; done=0;
     while (!done && ((line = readline(NULL)) != NULL)) {
-#ifdef HAVE_READLINE
+
       add_history(line);
-#endif
+
       yy_scan_string(line); yyparse();
       showstack();
 
       free(line); line=NULL;
     }
 
-#ifdef HAVE_READLINE
     if (interactive) {
       remove_history(0);
     }
-#endif
   }
-#ifdef MCHECK
-  mtrace();
-#endif
   return 0;
 }
